Class: Google::Cloud::GDCHardwareManagement::V1alpha::CreateZoneRequest
- Inherits:
-
Object
- Object
- Google::Cloud::GDCHardwareManagement::V1alpha::CreateZoneRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/gdchardwaremanagement/v1alpha/service.rb
Overview
A request to create a zone.
Instance Attribute Summary collapse
-
#parent ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
-
#zone ⇒ ::Google::Cloud::GDCHardwareManagement::V1alpha::Zone
Required.
-
#zone_id ⇒ ::String
Optional.
Instance Attribute Details
#parent ⇒ ::String
Returns Required. The project and location to create the zone in.
Format: projects/{project}/locations/{location}.
810 811 812 813 |
# File 'proto_docs/google/cloud/gdchardwaremanagement/v1alpha/service.rb', line 810 class CreateZoneRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. An optional unique identifier for this request. See AIP-155.
810 811 812 813 |
# File 'proto_docs/google/cloud/gdchardwaremanagement/v1alpha/service.rb', line 810 class CreateZoneRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#zone ⇒ ::Google::Cloud::GDCHardwareManagement::V1alpha::Zone
Returns Required. The zone to create.
810 811 812 813 |
# File 'proto_docs/google/cloud/gdchardwaremanagement/v1alpha/service.rb', line 810 class CreateZoneRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#zone_id ⇒ ::String
Returns Optional. ID used to uniquely identify the Zone within its parent scope.
This field should contain at most 63 characters and must start with
lowercase characters.
Only lowercase characters, numbers and - are accepted.
The - character cannot be the first or the last one.
A system generated ID will be used if the field is not set.
The zone.name field in the request will be ignored.
810 811 812 813 |
# File 'proto_docs/google/cloud/gdchardwaremanagement/v1alpha/service.rb', line 810 class CreateZoneRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |